.TEXT {
	font-size: 90%;
	font-family: arial,helvetica,sans-serif;
	}

.TEXTWIDE {
	font-size: 90%;
	font-family: arial,helvetica,sans-serif;
	}

.medium1 {
	font-size: 75%;
	font-family: arial,helvetica,sans-serif;
	}

.medium2 {
	font-size: 75%;
	font-family: verdana;
	}

.medium3 {
	font-size: 75%;
	font-family: courier;
	}
	
.medium4 {
	font-size: 75%;
	font-family: arial,helvetica,sans-serif;
	font-style: italic;
	}

.GUTTER1 {
	font-size: 85%;
    font-family: arial,helvetica,sans-serif;
    color:#ffcc66;
	}

.GUTTER2 {
	font-size: 75%;
        font-family: arial,helvetica,sans-serif;
	color:#ccccff;
	}
    
.GUTTER3 {
	font-size: 75%;
	font-family: arial,helvetica,sans-serif;
	color:#ffffff;
	text-decoration:none;
	}

A	{
	color:#0033CC;
	}
	
A.BOOK	{
	color:#085a29;
	font-weight: bold;
	}

A.BAR {
	font-size:85%;
	color:#ffffff;
	font-family: arial,helvetica,sans-serif;
	text-decoration:none;
	}

A.HELPBAR {
	color:#000000;
        font-size: 75%;
	font-family: arial,helvetica,sans-serif;
	text-decoration:none;
	}

A.GUTTER {
	color:#ffffff;
        font-size: 85%;
	font-family: arial,helvetica,sans-serif;
        text-decoration:none;
        }   
   
A.GUTTER1 {
	color:#ffcc66;
	font-size:85%;
	font-family: arial,helvetica,sans-serif;
	text-decoration:none;
	}

A.GUTTER2 {
	font-size: 75%;
	font-family: arial,helvetica,sans-serif;
	color:#ccccff;
	text-decoration:none;
	}
	
A.GUTTER3 {
	font-size: 75%;
	font-family: arial,helvetica,sans-serif;
	color:#ffffff;
	text-decoration:none;
	}

A.BUTTON {
	font-size: 75%;
	font-family: arial,helvetica,sans-serif;
	color:#000000;
	text-decoration:none;
	}

H1, .H1 {
	font-size: 125%;
	font-weight: bold;
	font-family: arial,helvetica,sans-serif;
	}

H2, .H2 {
	font-size: 125%;
	font-weight: bold;
	font-family: arial,helvetica,sans-serif;
	}

H3, .H3 {
	font-size: 100%;
	font-weight: bold;
	font-family: arial,helvetica,sans-serif;
	}

H4, .H4 {
	font-size: 100%;
	font-weight: bold;
	font-family: arial,helvetica,sans-serif;
	}

H5, .H5 {
	font-size: 85%;
	font-weight: bold;
	font-style: italic;
	font-family: arial,helvetica,sans-serif;
	}
	
.pmlinka {
	font-family: arial,helvetica,sans-serif;
	font-size:85%;
	font-weight:bold;
	color: #336699;
	text-align:center;
	vertical-align:baseline;                        
	text-decoration:none;
	}

.pmlinkna {
	font-family: arial,helvetica,sans-serif;
	font-size:85%;
	color: #336699;
	text-align:center;
	vertical-align:baseline;
	text-decoration:none;
	}

.taba {
	background:#FFFFFF;
 	text-align:center;
	vertical-align:baseline;
	}

.tabna {
	background:#CCCCCC;
	text-align:center;
	vertical-align:baseline;
	}

.dblinks {        
	font-size: 75%;
	font-family: arial,helvetica,sans-serif;
	color:#336699;
	text-decoration:none;
	}

A.popmenu:link { text-decoration: none; font-family: Verdana, Arial, Sans-serif; font-size: 11px; color: Navy; }
A.popmenu:visited { text-decoration: none; font-family: Verdana, Arial, Sans-serif; font-size: 11px;  color:#6C7F9A; }
A.popmenu:active { text-decoration: none; font-family: Verdana, Arial, Sans-serif; font-size: 11px;  color:#001A4F; }
A.popmenu:hover { text-decoration: underline; color:#038000;  font-family: Verdana, Arial, Sans-serif; font-size: 11px; }
.menutitle { font-family: Verdana, Arial, Sans-serif; font-size: 10px;  font-weight: bold; }
.fixedsize_skobka { color:#000084; font-size:10px; font-family:Arial,sans-serif; }

